==> xlniuxdata-vipgame-1.0.65-20160810.064343-38-sources.jar: com/xunlei/niux/data/vipgame/dao/MobileGuildDaoImpl.java <==
package com.xunlei.niux.data.vipgame.dao;

import com.ferret.common.dao.BaseDaoImpl;
import com.xunlei.niux.data.vipgame.dto.GuildGameDto;
import com.xunlei.niux.data.vipgame.dto.MobileGameApkDto;
import com.xunlei.niux.data.vipgame.dto.MobileGuildSpreadDTO;
import com.xunlei.niux.data.vipgame.util.ObjectMapper;
import com.xunlei.niux.data.vipgame.vo.Games;
import com.xunlei.niux.data.vipgame.vo.mobilegameapkversion.MobileGameApk;
import com.xunlei.niux.data.vipgame.vo.mobileguild.MobileGuildSpread;
import org.apache.commons.lang.StringUtils;
import org.springframework.jdbc.core.RowMapper;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by Dean on 2016/4/21.
 */
public class MobileGuildDaoImpl extends BaseDaoImpl implements MobileGuildDao {


    public List<GuildGameDto> getGuildGames(long userId){
        StringBuilder sql=new StringBuilder();
        sql.append(" SELECT  g.gameId,g.gameName,t.firstSpell,t.outputTime,IFNULL(s.hasChecked,0) hasChecked ");
        sql.append(" from mobileguildgame t ");
        sql.append(" LEFT JOIN mobileguildspread s on t.gameId=s.gameId and s.guildUserId = "+userId);
        sql.append(" LEFT JOIN games  g on t.gameId=g.gameId WHERE 1=1 and t.isDel=0 ");
        return getJdbcTemplate().query(sql.toString(),new ObjectMapper(GuildGameDto.class));
    }

    public List<MobileGuildSpreadDTO> getGuildSpread(long uid,String seqIds,int pageIndex,int pageSize){
        StringBuilder sql=new StringBuilder();
        List<Object> args=new ArrayList<Object>();
        sql.append(" SELECT t.appSize, t.appVersion,t.downloadUrl,t.gameId, t.guildUserId, t.inputTime,");
        sql.append("(case WHEN t.hasFinished=1 then '打包成功' else '打包中' end)  hasFinished,");
        sql.append(" t.platform,t.seqId,g.gameName ");
        sql.append(" FROM mobileguildspread t ");
        sql.append(" LEFT JOIN games g ON t.gameId = g.gameId ");
        sql.append(" WHERE 1=1 ");
        if(uid!=0){
            sql.append(" and t.guildUserId = ? ");
            args.add(uid);
        }
        if(StringUtils.isNotEmpty(seqIds)){
            sql.append(" and t.seqId in ( "+seqIds+" ) ");
        }
        sql.append(" order by t.inputTime desc ");
        if(pageIndex>0&&pageSize>0) {
            sql.append(" limit ?,? ");
            int pageStart = (pageIndex - 1) * pageSize < 0 ? 0 : (pageIndex - 1) * pageSize;
            args.add(pageStart);
            args.add(pageSize);
        }
        return getJdbcTemplate().query(sql.toString(),args.toArray(),new ObjectMapper(MobileGuildSpreadDTO.class,false,false));
    }

    public int countGuildSpread(long uid,String seqIds){
        StringBuilder sql=new StringBuilder();
        List<Object> args=new ArrayList<Object>();
        sql.append(" SELECT count(1) ");
        sql.append(" FROM mobileguildspread t ");
        sql.append(" LEFT JOIN games g ON t.gameId = g.gameId ");
        sql.append(" WHERE 1=1 ");
        if(uid!=0){
            sql.append(" and t.guildUserId = ? ");
            args.add(uid);
        }
        if(StringUtils.isNotEmpty(seqIds)){
            sql.append(" and t.seqId in ( "+seqIds+" ) ");
        }
        sql.append(" order by t.inputTime desc ");
        return getJdbcTemplate().queryForInt(sql.toString(),args.toArray());
    }

    public List<MobileGuildSpread> getGuildSpread(long uid,String seqIds){
        StringBuilder sql=new StringBuilder();
        List<Object> args=new ArrayList<Object>();
        sql.append(" SELECT t.seqId, t.guildUserId,t.gameId,t.appVersion, t.appSize,t.channelId,t.apkId, ");
        sql.append(" t.platform,t.inputTime,t.downloadUrl,t.hasFinished");
        sql.append(" FROM mobileguildspread t ");
        sql.append(" WHERE 1=1 ");
        if(uid!=0){
            sql.append(" and t.guildUserId = ? ");
            args.add(uid);
        }
        if(StringUtils.isNotEmpty(seqIds)){
            sql.append(" and t.seqId in ( "+seqIds+" ) ");
        }
        sql.append(" order by t.inputTime desc ");
        return getJdbcTemplate().query(sql.toString(),new ObjectMapper(MobileGuildSpread.class));
    }

    public List<MobileGuildSpreadDTO> getGuildGameInfo(String gameIds){
        StringBuilder sql=new StringBuilder();
        sql.append(" SELECT t.gameId,t.appVersion,g.gameNo,a.apkName,g.appSize,t.apkId from mobileguildgame t ");
        sql.append(" LEFT JOIN games g on t.gameId=g.gameId LEFT JOIN mobileGameApk a on t.apkId=a.apkId WHERE 1=1 ");
        if(StringUtils.isNotEmpty(gameIds)){
            sql.append(" and t.gameId in ( "+gameIds+" ) ");
        }
       return getJdbcTemplate().query(sql.toString(),new ObjectMapper(MobileGuildSpreadDTO.class,false,false));
    }

    public List<MobileGameApkDto> getGameApk(String gameIds){
        StringBuilder sql=new StringBuilder();
        sql.append(" SELECT t.*,g.gameNo,g.appSize from mobilegameapk t ");
        sql.append(" left join games g on t.gameId=g.gameId ");
        sql.append(" where  not EXISTS  ( SELECT null from mobilegameapk a where a.gameId=t.gameId  and a.apkId> t.apkId ) ");
        if(StringUtils.isNotEmpty(gameIds)){
            sql.append(" and t.gameId in ( "+gameIds+" ) ");
        }
        return getJdbcTemplate().query(sql.toString(),new ObjectMapper(MobileGameApkDto.class));
    }

    public List<MobileGuildSpread> getPackagedSpreads( String apkIds, String gameids, String uids){
        StringBuilder sql=new StringBuilder();
        sql.append(" SELECT * from mobileguildspread  where 1=1 ");
        if(StringUtils.isNotEmpty(gameids)){
            sql.append(" and gameId in ( "+gameids+" ) ");
        }
        if(StringUtils.isNotEmpty(uids)){
            sql.append(" and guildUserId in ( "+uids+" ) ");
        }
        if(StringUtils.isNotEmpty(apkIds)){
            sql.append(" and apkId in ( "+apkIds+" ) ");
        }

        return getJdbcTemplate().query(sql.toString(),new ObjectMapper(MobileGuildSpread.class,false,false));
    }

}

==> xlniuxdata-vipgame-1.0.65-20160810.070245-39-sources.jar: com/xunlei/niux/data/vipgame/dao/MobileGuildDaoImpl.java <==
package com.xunlei.niux.data.vipgame.dao;

import com.ferret.common.dao.BaseDaoImpl;
import com.xunlei.niux.data.vipgame.dto.GuildGameDto;
import com.xunlei.niux.data.vipgame.dto.MobileGameApkDto;
import com.xunlei.niux.data.vipgame.dto.MobileGuildSpreadDTO;
import com.xunlei.niux.data.vipgame.util.ObjectMapper;
import com.xunlei.niux.data.vipgame.vo.Games;
import com.xunlei.niux.data.vipgame.vo.mobilegameapkversion.MobileGameApk;
import com.xunlei.niux.data.vipgame.vo.mobileguild.MobileGuildSpread;
import org.apache.commons.lang.StringUtils;
import org.springframework.jdbc.core.RowMapper;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by Dean on 2016/4/21.
 */
public class MobileGuildDaoImpl extends BaseDaoImpl implements MobileGuildDao {


    public List<GuildGameDto> getGuildGames(long userId){
        StringBuilder sql=new StringBuilder();
        sql.append(" SELECT  g.gameId,g.gameName,t.firstSpell,t.outputTime,IFNULL(s.hasChecked,0) hasChecked ");
        sql.append(" from mobileguildgame t ");
        sql.append("  LEFT JOIN mobileguildspread s on t.gameId=s.gameId ");
        sql.append(" LEFT JOIN games  g on t.gameId=g.gameId WHERE 1=1 and t.isDel=0 ");
        if(userId!=0){
            sql.append(" and s.guildUserId = "+userId);
        }
        return getJdbcTemplate().query(sql.toString(),new ObjectMapper(GuildGameDto.class));
    }

    public List<MobileGuildSpreadDTO> getGuildSpread(long uid,String seqIds,int pageIndex,int pageSize){
        StringBuilder sql=new StringBuilder();
        List<Object> args=new ArrayList<Object>();
        sql.append(" SELECT t.appSize, t.appVersion,t.downloadUrl,t.gameId, t.guildUserId, t.inputTime,");
        sql.append("(case WHEN t.hasFinished=1 then '打包成功' else '打包中' end)  hasFinished,");
        sql.append(" t.platform,t.seqId,g.gameName ");
        sql.append(" FROM mobileguildspread t ");
        sql.append(" LEFT JOIN games g ON t.gameId = g.gameId ");
        sql.append(" WHERE 1=1 ");
        if(uid!=0){
            sql.append(" and t.guildUserId = ? ");
            args.add(uid);
        }
        if(StringUtils.isNotEmpty(seqIds)){
            sql.append(" and t.seqId in ( "+seqIds+" ) ");
        }
        sql.append(" order by t.inputTime desc ");
        if(pageIndex>0&&pageSize>0) {
            sql.append(" limit ?,? ");
            int pageStart = (pageIndex - 1) * pageSize < 0 ? 0 : (pageIndex - 1) * pageSize;
            args.add(pageStart);
            args.add(pageSize);
        }
        return getJdbcTemplate().query(sql.toString(),args.toArray(),new ObjectMapper(MobileGuildSpreadDTO.class,false,false));
    }

    public int countGuildSpread(long uid,String seqIds){
        StringBuilder sql=new StringBuilder();
        List<Object> args=new ArrayList<Object>();
        sql.append(" SELECT count(1) ");
        sql.append(" FROM mobileguildspread t ");
        sql.append(" LEFT JOIN games g ON t.gameId = g.gameId ");
        sql.append(" WHERE 1=1 ");
        if(uid!=0){
            sql.append(" and t.guildUserId = ? ");
            args.add(uid);
        }
        if(StringUtils.isNotEmpty(seqIds)){
            sql.append(" and t.seqId in ( "+seqIds+" ) ");
        }
        sql.append(" order by t.inputTime desc ");
        return getJdbcTemplate().queryForInt(sql.toString(),args.toArray());
    }

    public List<MobileGuildSpread> getGuildSpread(long uid,String seqIds){
        StringBuilder sql=new StringBuilder();
        List<Object> args=new ArrayList<Object>();
        sql.append(" SELECT t.seqId, t.guildUserId,t.gameId,t.appVersion, t.appSize,t.channelId,t.apkId, ");
        sql.append(" t.platform,t.inputTime,t.downloadUrl,t.hasFinished");
        sql.append(" FROM mobileguildspread t ");
        sql.append(" WHERE 1=1 ");
        if(uid!=0){
            sql.append(" and t.guildUserId = ? ");
            args.add(uid);
        }
        if(StringUtils.isNotEmpty(seqIds)){
            sql.append(" and t.seqId in ( "+seqIds+" ) ");
        }
        sql.append(" order by t.inputTime desc ");
        return getJdbcTemplate().query(sql.toString(),new ObjectMapper(MobileGuildSpread.class));
    }

    public List<MobileGuildSpreadDTO> getGuildGameInfo(String gameIds){
        StringBuilder sql=new StringBuilder();
        sql.append(" SELECT t.gameId,t.appVersion,g.gameNo,a.apkName,g.appSize,t.apkId from mobileguildgame t ");
        sql.append(" LEFT JOIN games g on t.gameId=g.gameId LEFT JOIN mobileGameApk a on t.apkId=a.apkId WHERE 1=1 ");
        if(StringUtils.isNotEmpty(gameIds)){
            sql.append(" and t.gameId in ( "+gameIds+" ) ");
        }
       return getJdbcTemplate().query(sql.toString(),new ObjectMapper(MobileGuildSpreadDTO.class,false,false));
    }

    public List<MobileGameApkDto> getGameApk(String gameIds){
        StringBuilder sql=new StringBuilder();
        sql.append(" SELECT t.*,g.gameNo,g.appSize from mobilegameapk t ");
        sql.append(" left join games g on t.gameId=g.gameId ");
        sql.append(" where  not EXISTS  ( SELECT null from mobilegameapk a where a.gameId=t.gameId  and a.apkId> t.apkId ) ");
        if(StringUtils.isNotEmpty(gameIds)){
            sql.append(" and t.gameId in ( "+gameIds+" ) ");
        }
        return getJdbcTemplate().query(sql.toString(),new ObjectMapper(MobileGameApkDto.class));
    }

    public List<MobileGuildSpread> getPackagedSpreads( String apkIds, String gameids, String uids){
        StringBuilder sql=new StringBuilder();
        sql.append(" SELECT * from mobileguildspread  where 1=1 ");
        if(StringUtils.isNotEmpty(gameids)){
            sql.append(" and gameId in ( "+gameids+" ) ");
        }
        if(StringUtils.isNotEmpty(uids)){
            sql.append(" and guildUserId in ( "+uids+" ) ");
        }
        if(StringUtils.isNotEmpty(apkIds)){
            sql.append(" and apkId in ( "+apkIds+" ) ");
        }

        return getJdbcTemplate().query(sql.toString(),new ObjectMapper(MobileGuildSpread.class,false,false));
    }

}
